@@ -22,7 +22,7 @@
 
 #include <QFile>
 #include <QList>
-#include <QRegExp>
+#include <QRegularExpression>
 #include <QStandardPaths>
 #include <QTextStream>
 
@@ -72,7 +72,7 @@ QString WordCompletion::makeCompletion(const QString &text)
         d->lastText = text;
         KCompletion::clear();
 
-        int border = text.lastIndexOf(QRegExp(QStringLiteral("\\W")));
+        int border = text.lastIndexOf(QRegularExpression(QStringLiteral("\\W")));
         QString suffix = text.right(text.length() - border - 1).toLower();
         QString prefix = text.left(border + 1);
 
@@ -205,11 +205,11 @@ bool WordCompletion::setWordList(const QString &wordlist)
 
 void WordCompletion::addSentence(const QString &sentence)
 {
-    const QStringList words = sentence.split(QRegExp(QStringLiteral("\\W")));
+    const QStringList words = sentence.split(QRegularExpression(QStringLiteral("\\W")));
 
     QStringList::ConstIterator it;
     for (it = words.constBegin(); it != words.constEnd(); ++it) {
-        if (!(*it).contains(QRegExp(QStringLiteral("\\d|_")))) {
+        if (!(*it).contains(QRegularExpression(QStringLiteral("\\d|_")))) {
             QString key = (*it).toLower();
             if (d->map.contains(key))
                 d->map[key] += 1;
